# Generated by Django 2.2.15 on 2020-11-29 17:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_we', '0004_auto_20190820_1220'),
    ]

    operations = [
        migrations.AlterField(
            model_name='componentauthtokenrefreshloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='componenttokenrefreshloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='componentverifyticketloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='subscribeuserinfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='ticketrefreshloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
        migrations.AlterField(
            model_name='tokenrefreshloginfo',
            name='status',
            field=models.BooleanField(default=True, help_text='Status', verbose_name='status'),
        ),
    ]
