# -*- coding: utf-8 -*-
# Generated by Django 1.11.22 on 2019-08-19 08:40
from __future__ import unicode_literals

from django.db import migrations, models
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('django_we', '0002_componentverifyticketloginfo'),
    ]

    operations = [
        migrations.CreateModel(
            name='SubscribeUserInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.BooleanField(db_index=True, default=True, help_text='Status', verbose_name='status')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Create Time', verbose_name='created_at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Update Time', verbose_name='updated_at')),
                ('unionid', models.CharField(blank=True, db_index=True, help_text='UnionID', max_length=32, null=True, verbose_name='unionid')),
                ('openid', models.CharField(blank=True, db_index=True, help_text='OpenID', max_length=32, null=True, verbose_name='openid')),
                ('nickname', models.CharField(blank=True, help_text='\u6635\u79f0', max_length=32, null=True, verbose_name='nickname')),
                ('sex', models.IntegerField(choices=[(0, '\u672a\u77e5'), (1, '\u7537'), (2, '\u5973')], db_index=True, default=0, help_text='\u6027\u522b', verbose_name='sex')),
                ('headimgurl', models.URLField(blank=True, help_text='\u5934\u50cf', null=True, verbose_name='headimgurl')),
                ('country', models.CharField(blank=True, help_text='\u56fd\u5bb6', max_length=16, null=True, verbose_name='country')),
                ('province', models.CharField(blank=True, help_text='\u7701\u4efd', max_length=16, null=True, verbose_name='province')),
                ('city', models.CharField(blank=True, help_text='\u57ce\u5e02', max_length=16, null=True, verbose_name='city')),
                ('subscribe', models.IntegerField(db_index=True, default=1, help_text='\u662f\u5426\u5173\u6ce8', verbose_name='subscribe')),
                ('subscribe_time', models.IntegerField(default=0, help_text='\u5173\u6ce8\u65f6\u95f4', verbose_name='subscribe_time')),
                ('subscribe_scene', models.CharField(blank=True, help_text='\u5173\u6ce8\u6e20\u9053\u6765\u6e90', max_length=32, null=True, verbose_name='subscribe_scene')),
                ('groupid', models.IntegerField(default=0, help_text='\u5206\u7ec4ID', verbose_name='groupid')),
                ('tagid_list', jsonfield.fields.JSONField(blank=True, help_text='\u6807\u7b7eID\u5217\u8868', null=True, verbose_name='tagid_list')),
                ('qr_scene', models.IntegerField(default=0, help_text='\u4e8c\u7ef4\u7801\u626b\u7801\u573a\u666f', verbose_name='qr_scene')),
                ('qr_scene_str', models.CharField(blank=True, help_text='\u4e8c\u7ef4\u7801\u626b\u7801\u573a\u666f\u63cf\u8ff0', max_length=64, null=True, verbose_name='qr_scene_str')),
                ('language', models.CharField(default='zh_CN', help_text='\u8bed\u8a00', max_length=8, verbose_name='language')),
                ('remark', models.CharField(blank=True, help_text='\u5907\u6ce8', max_length=16, null=True, verbose_name='remark')),
            ],
            options={
                'verbose_name': 'subscribeuserinfo',
                'verbose_name_plural': 'subscribeuserinfo',
            },
        ),
    ]
